==> snapstraction-0.3.5a1-py2-none-any.whl: snapstraction/build.py <==
"""SNAPstraction over calling SNAPbuild"""
import logging
import subprocess
import os
import sys

from distutils.sysconfig import get_python_lib

log = logging.getLogger(__name__)


def call(script, module, core, includes=None, platform=None, output_path=None):  # noqa
    """Call out to snapbuild"""

    try:
        from snapbuild import snapbuild
    except ImportError:
        log.exception("SNAPbuild not installed.")
        raise

    if not includes:
        includes = []

    snapbuild_args = ['-v', script, '-m', module, '-c', core]

    # This is a check for "Are we being executed under an active virtualenv?"
    # Different from "Are we installed in a virtualenv"
    if 'VIRTUAL_ENV' in os.environ:
        includes.insert(0, os.path.abspath(get_python_lib(prefix=os.environ['VIRTUAL_ENV'])))

    for i in includes:
        snapbuild_args.append('-I')
        snapbuild_args.append(i)

    if platform:
        snapbuild_args += ['-p', platform]

    if output_path:
        snapbuild_args += ['-o', output_path]

    log.debug("SNAPbuild args for call: %r", snapbuild_args)

    # The _ here is a placeholder, the wrapper normally expects sys.argv
    # and has to strip off the first element (progname)
    try:
        output = snapbuild.call(args=['_'] + snapbuild_args, stderr=subprocess.STDOUT)
        log.info("SNAPbuild output: %r", output)
    except subprocess.CalledProcessError as e:
        log.exception("SNAPbuild Error!")
        sys.stderr.write(e.output)
        exit(e.returncode)
    except:
        log.exception("SNAPbuild Error!")
    else:
        crc = None
        # Extract the CRC from the output
        for line in output.split('\n'):
            if "SNAPpy CRC" in line:
                crc = line.split()[-1]
                break

        return crc

    return None

==> snapstraction-0.8.1-py2-none-any.whl: snapstraction/build.py <==
"""SNAPstraction over calling SNAPbuild"""
import logging
import subprocess
import sys

from util import executing_in_virtualenv, get_virtualenv_path

log = logging.getLogger(__name__)


def call(script, module, core, includes=None, platform=None, output_path=None):  # noqa
    """Call out to snapbuild"""

    try:
        from snapbuild import snapbuild
    except ImportError:
        log.exception("SNAPbuild not installed.")
        raise

    if not includes:
        includes = []

    snapbuild_args = ['-v', script, '-m', module, '-c', core]

    # This is a check for "Are we being executed under an active virtualenv?"
    # Different from "Are we installed in a virtualenv"
    if executing_in_virtualenv():
        includes.insert(0, get_virtualenv_path())

    for i in includes:
        snapbuild_args.append('-I')
        snapbuild_args.append(i)

    if platform:
        snapbuild_args += ['-p', platform]

    if output_path:
        snapbuild_args += ['-o', output_path]

    log.debug("SNAPbuild args for call: %r", snapbuild_args)

    # The _ here is a placeholder, the wrapper normally expects sys.argv
    # and has to strip off the first element (progname)
    try:
        output = snapbuild.call(args=['_'] + snapbuild_args, stderr=subprocess.STDOUT)
        log.info("SNAPbuild output: %r", output)
    except subprocess.CalledProcessError as e:
        log.exception("SNAPbuild Error!")
        sys.stderr.write(e.output)
        exit(e.returncode)
    except:
        log.exception("SNAPbuild Error!")
    else:
        crc = None
        # Extract the CRC from the output
        for line in output.split('\n'):
            if "SNAPpy CRC" in line:
                crc = line.split()[-1]
                break

        return crc

    return None
